Router

Struct Router 

pub struct Router<S, R = Response> { /* private fields */ }
Fixed-path router with middleware chain.

Implementations

Source

impl<S, R> Router<S, R>
where S: Clone + Send + Sync + 'static, R: From<Response> + Send + 'static,

pub fn new(state: S) -> Self

Creates an empty router bound to a clonable state value.

pub fn get<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a GET route.

pub fn post<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a POST route.

pub fn put<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a PUT route.

pub fn delete<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a DELETE route.

pub fn patch<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a PATCH route.

pub fn head<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a HEAD route.

pub fn options<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers an OPTIONS route.

pub fn any<F, Fut>(self, path: impl Into<String>, handler: F) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a route for any method.

pub fn on<F, Fut>( self, method: Method, path: impl Into<String>, handler: F, ) -> Self
where F: Fn(RoutedRequest, S) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Registers a route for an explicit method token.

pub fn middleware<F, Fut>(self, middleware: F) -> Self
where F: Fn(RoutedRequest, S, Next<S, R>) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static,

Adds a middleware to the end of the chain.

The middleware applies to all routes currently registered on this router and to any routes added later on the same router value. Middleware attached to another router does not leak across Self::merge.

pub fn merge(self, other: Self) -> Self

Merges routes and middleware from another router with the same state.

pub async fn handle(&self, request: Request) -> R

Dispatches a request entirely in-process.

pub async fn handle_routed(&self, request: RoutedRequest) -> R

Dispatches a routed request entirely in-process.